BatchResponse class

Response from batchRequest request

Constructors

BatchResponse({required dynamic status, required dynamic message, required dynamic rawData, required String batchId, required String batchName})
BatchResponse.create(String cb, String data)
factory

Properties

batchId String
final
batchName String
final
hashCode int
The hash code for this object.
no setterinherited
message String
getter/setter pairinherited
rawData String?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status TransactionStatus
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited