FastRefundResponse class

Fast Refund response from fastRefund request

Constructors

FastRefundResponse({required dynamic status, required dynamic message, required dynamic rawData, required double amount, String? sourceCode, String? cardType, String? accountNumber, String? tid, String? transactionId, String? aadeTransactionId})
FastRefundResponse.create(String cb, String data)
factory

Properties

aadeTransactionId String?
getter/setter pair
accountNumber String?
getter/setter pair
amount double
getter/setter pair
cardType String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String
getter/setter pairinherited
rawData String?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceCode String?
getter/setter pair
status TransactionStatus
getter/setter pairinherited
tid String?
getter/setter pair
transactionId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited