SetModeResponse class

Response from setMode request

Constructors

SetModeResponse({required dynamic status, required dynamic message, required dynamic rawData})
SetModeResponse.create(String cb, String data)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
getter/setter pairinherited
rawData String?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status TransactionStatus
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited