VivaWalletPos class

Flutter plugin for integration with Viva Wallet Pos

(https://developer.vivawallet.com/apis-for-point-of-sale/)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

abort({String? merchantKey}) Future<AbortResponse>
Abort ongoing transaction
activatePos({required String apikey, required String apiSecret, String? sourceID, String? pinCode, bool skipExternalDeviceSetup = true, bool activateMoto = false, bool activateQRCodes = false, AppOrientation appOrientation = AppOrientation.portrait}) Future<ActivationResponse>
Activate POS method
batch({required BatchCommand command, String? batchId, String? batchName}) Future<BatchResponse>
Batch Request
cancel({String? merchantKey, String? referenceNumber, required double amount, String? orderCode, String? shortOrderCode, DateTime? txnDateFrom, DateTime? txnDateTo, bool showReceipt = true, bool showTransactionResult = true, bool showRating = true, String? aadeProviderId, String? aadeProviderSignatureData, String? aadeProviderSignature}) Future<TransactionResponse>
Cancel transaction -> refund request
cancelVivaFiscalGreece({required int amount, String? orderCode, bool showReceipt = true, bool showTransactionResult = true, String? fiscalisationData}) Future<TransactionResponse>
(https://developer.vivawallet.com/apis-for-point-of-sale/card-terminal-apps/android-app/cancel/)
fastRefund({String? referenceNumber, required double amount, String? sourceCode, bool showReceipt = true, bool showTransactionResult = true, bool showRating = true}) Future<FastRefundResponse>
Fast Refund request
getActivationCode() Future<GetActivationCodeResponse>
Get Activation Code request
isvSale({String? merchantKey, required String clientTransactionId, required double amount, double? tipAmount, bool showReceipt = true, bool showTransactionResult = true, bool showRating = true, Map<String, dynamic>? saleToAcquirerData, double? isvAmount, required String isvClientId, required String isvClientSecret, String? isvMerchantId, int isvCurrencyCode = 978, String isvSourceCode = 'Default', String? isvCustomerTrns, int? isvMerchantSourceCode, String? isvClientTransactionId}) Future<TransactionResponse>
Make a sale with the ISV schema
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reprintTransaction({required String orderCode}) Future<ReprintTransactionResponse>
Reprint previously completed transaction
resetTerminal({bool softReset = true}) Future<ResetTerminalResponse>
Reset Terminal (soft or full reset)
sale({String? merchantKey, required String clientTransactionId, required double amount, double? tipAmount, bool showReceipt = true, bool showTransactionResult = true, bool showRating = true, Map<String, dynamic>? saleToAcquirerData}) Future<TransactionResponse>
Make a sale
saleRequestGreeceAade({required String clientTransactionId, required double amount, String? aadeProviderId, String? aadeProviderSignatureData, String? aadeProviderSignature, double? tipAmount, String? isvClientId, String? isvClientSecret, int? isvAmount, int? isvCurrencyCode, int? isvSourceCode, String? isvCustomerTrns, String? isvClientTransactionId, bool showReceipt = true, bool showTransactionResult = true}) Future<TransactionResponse>
Make a sale for Greece AADE parameters for Providers except Viva Fiscal
saleVivaIsvFiscalGreece({required String clientTransactionId, required int amount, int? tipAmount, String? isvClientId, String? isvClientSecret, int? isvAmount, int? isvCurrencyCode, int? isvSourceCode, String? isvCustomerTrns, String? isvClientTransactionId, bool showReceipt = true, bool showTransactionResult = true, String? fiscalisationData}) Future<TransactionResponse>
Make a sale with Viva Fiscalisation for Greece for ISV
sendLogs() Future<SendLogsResponse>
Send logs to viva devs
setDecimalAmountMode({required bool decimalMode}) Future<SetDecimalAmountModeResponse>
Set decimal amount mode (works only on Card Terminal Apps)
setMode({required ApplicationMode mode, required String pin}) Future<SetModeResponse>
Set POS operation mode
setPrintingSettings({bool? businessDescriptionEnabled, BusinessDescriptionType? businessDescriptionType, bool? printLogoOnMerchantReceipt, bool? printVATOnMerchantReceipt, bool? isBarcodeEnabled, bool? printAddressOnReceipt, bool? isMerchantReceiptEnabled, bool? isCustomerReceiptEnabled}) Future<SetPrintingSettingsResponse>
Set printing settings
toString() String
A string representation of this object.
inherited
transactionDetails({String? merchantKey, required String clientTransactionId, required String sourceTerminalId}) Future<TransactionResponse>
Transaction Details Request

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance VivaWalletPos
no setter