SetPrintingSettingsResponse class
Response from setPrintingSettings request
Constructors
- SetPrintingSettingsResponse({required dynamic status, required dynamic message, required dynamic rawData, required BusinessDescriptionType businessDescriptionType, required bool printLogoOnMerchantReceipt, required bool printVATOnMerchantReceipt, required bool isBarcodeEnabled, required bool businessDescriptionEnabled, required bool printAddressOnReceipt, required bool isMerchantReceiptEnabled, required bool isCustomerReceiptEnabled})
- SetPrintingSettingsResponse.create(String cb, String data)
-
factory
Properties
- businessDescriptionEnabled → bool
-
final
- businessDescriptionType → BusinessDescriptionType
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBarcodeEnabled → bool
-
final
- isCustomerReceiptEnabled → bool
-
final
- isMerchantReceiptEnabled → bool
-
final
- message ↔ String
-
getter/setter pairinherited
- printAddressOnReceipt → bool
-
final
- printLogoOnMerchantReceipt → bool
-
final
- printVATOnMerchantReceipt → bool
-
final
- rawData ↔ String?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ TransactionStatus
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited